pub type TryLockResult<Guard> = Result<Guard, TryLockError<Guard>>;Expand description
A type alias for the result of a nonblocking locking method.
For more information, see LockResult. A TryLockResult doesn’t
necessarily hold the associated guard in the Err type as the lock might not
have been acquired for other reasons.
Aliased Type
pub enum TryLockResult<Guard> {
Ok(Guard),
Err(TryLockError<Guard>),
}Variants
Ok(Guard)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Contains the success value
Err(TryLockError<Guard>)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Contains the error value